var NAVTREEINDEX4 =
{
"classviennacl_1_1linalg_1_1jacobi__precond.html":[6,0,0,4,32],
"classviennacl_1_1linalg_1_1jacobi__precond.html#a4dc33d4e561b2f29bd37131a1c015622":[6,0,0,4,32,2],
"classviennacl_1_1linalg_1_1jacobi__precond.html#a5d3e48bbec7300c929d58e445455f4dc":[6,0,0,4,32,1],
"classviennacl_1_1linalg_1_1jacobi__precond.html#a8484f42e58dc181682e8b0d7c5e59c2a":[6,0,0,4,32,0],
"classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html":[6,0,0,4,33],
"classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html#a02ba836483f54534222e2d161f5565fe":[6,0,0,4,33,1],
"classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html#a3093b690a945ff6cd760ea3d185383f4":[6,0,0,4,33,2],
"classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html#ac157dcfa0588c12f721fd1f0b492d222":[6,0,0,4,33,0],
"classviennacl_1_1linalg_1_1jacobi__tag.html":[6,0,0,4,34],
"classviennacl_1_1linalg_1_1lanczos__tag.html":[6,0,0,4,35],
"classviennacl_1_1linalg_1_1lanczos__tag.html#a3ce84b79a3ff77dd91a656232311cd52":[6,0,0,4,35,4],
"classviennacl_1_1linalg_1_1lanczos__tag.html#a47e14babee64097056526536b277dbae":[6,0,0,4,35,5],
"classviennacl_1_1linalg_1_1lanczos__tag.html#a4e07073e383c1f5ed160d007f05d6eb3":[6,0,0,4,35,6],
"classviennacl_1_1linalg_1_1lanczos__tag.html#a8a743b9f474124a0f779ed35c6f6a684a5a98f73ee4246c0d97c82917edeca27e":[6,0,0,4,35,2],
"classviennacl_1_1linalg_1_1lanczos__tag.html#a8a743b9f474124a0f779ed35c6f6a684a8ecf6c75a5bd6248e628651a83a9adf1":[6,0,0,4,35,1],
"classviennacl_1_1linalg_1_1lanczos__tag.html#a8a743b9f474124a0f779ed35c6f6a684a937ee8052e51309672b2bcdba4bb015e":[6,0,0,4,35,0],
"classviennacl_1_1linalg_1_1lanczos__tag.html#aa71eae96da7f83e2c510ae02a2c7dbce":[6,0,0,4,35,3],
"classviennacl_1_1linalg_1_1lanczos__tag.html#aaad9aa2dc06eb4a5ca272d7fc78fb072":[6,0,0,4,35,7],
"classviennacl_1_1linalg_1_1lanczos__tag.html#aad5c2c34a2b41e2a6a9b52dedd1d2ecf":[6,0,0,4,35,8],
"classviennacl_1_1linalg_1_1lanczos__tag.html#abfff89303690a662fab2fbabcca2ee25":[6,0,0,4,35,11],
"classviennacl_1_1linalg_1_1lanczos__tag.html#ae744c43467774ee300f5fab0c607aed1":[6,0,0,4,35,10],
"classviennacl_1_1linalg_1_1lanczos__tag.html#af2126adae7cd63d5c9c380066cdfabf1":[6,0,0,4,35,9],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html":[6,0,0,4,37],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#a08ce2880f2fcf6f0ce9a173f03345a3c":[6,0,0,4,37,2],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#a17d99c4efd9a09e794088c794b56a13c":[6,0,0,4,37,4],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#a235da03c3d4bd28739cb2a8677a6a5c3":[6,0,0,4,37,5],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#a848e937573ac5676287f45bcd597e6c0":[6,0,0,4,37,7],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#ab868f1d48b8d1150e994c4b8ce752f1b":[6,0,0,4,37,6],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#ad0f4d72e090336e3e638e6514841ae47":[6,0,0,4,37,0],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#ae02f0e5429c90b464d59924a31d55616":[6,0,0,4,37,3],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html#afb0c3e7b89c1f95d8fc27a5c58faa6f7":[6,0,0,4,37,1],
"classviennacl_1_1linalg_1_1nmf__config.html":[6,0,0,4,38],
"classviennacl_1_1linalg_1_1nmf__config.html#a031a7591b5f6de300749037b39ad5db7":[6,0,0,4,38,13],
"classviennacl_1_1linalg_1_1nmf__config.html#a36fe78d7d2e80e41e4e7546f01511840":[6,0,0,4,38,10],
"classviennacl_1_1linalg_1_1nmf__config.html#a494899ccb2fed620eb7fb69da5fc46c0":[6,0,0,4,38,4],
"classviennacl_1_1linalg_1_1nmf__config.html#a684af5e5f29515dc10e6bf53f598ab19":[6,0,0,4,38,2],
"classviennacl_1_1linalg_1_1nmf__config.html#a78285495f87a9f6aade57de8c73b6c31":[6,0,0,4,38,3],
"classviennacl_1_1linalg_1_1nmf__config.html#a875e5f082abe21568f75b36cc7b590b2":[6,0,0,4,38,1],
"classviennacl_1_1linalg_1_1nmf__config.html#a992720e64934be9f6e0e940ee5bbdfca":[6,0,0,4,38,8],
"classviennacl_1_1linalg_1_1nmf__config.html#a9fcce38eac47da2bdb7c597855322627":[6,0,0,4,38,5],
"classviennacl_1_1linalg_1_1nmf__config.html#ab11824e81b89c6703a6a5591cad1ddef":[6,0,0,4,38,7],
"classviennacl_1_1linalg_1_1nmf__config.html#ab948223929be79e20a1050146210ec6d":[6,0,0,4,38,6],
"classviennacl_1_1linalg_1_1nmf__config.html#abd93762ba5ef8bcff896d8455a980dea":[6,0,0,4,38,0],
"classviennacl_1_1linalg_1_1nmf__config.html#abdd2952e2501292d39f410a799307122":[6,0,0,4,38,12],
"classviennacl_1_1linalg_1_1nmf__config.html#ae0afaec61b786cff9ec7a92bf1d3b437":[6,0,0,4,38,11],
"classviennacl_1_1linalg_1_1nmf__config.html#af13bdd7b8374d0968e87511ad840d918":[6,0,0,4,38,9],
"classviennacl_1_1linalg_1_1no__precond.html":[6,0,0,4,39],
"classviennacl_1_1linalg_1_1no__precond.html#af18336a2ed53dadf3a9ef61ea7bede00":[6,0,0,4,39,0],
"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__prod.html":[6,0,0,4,3,0,18],
"classviennacl_1_1linalg_1_1power__iter__tag.html":[6,0,0,4,40],
"classviennacl_1_1linalg_1_1power__iter__tag.html#a2940a548e8543936ffdd93170ab8b8ce":[6,0,0,4,40,1],
"classviennacl_1_1linalg_1_1power__iter__tag.html#a79f4ba9e23ebb8692badacdfd32d246e":[6,0,0,4,40,3],
"classviennacl_1_1linalg_1_1power__iter__tag.html#a829b376442fbba41a3a7398a32f69b67":[6,0,0,4,40,2],
"classviennacl_1_1linalg_1_1power__iter__tag.html#ade62a68b85d3187a7470345f46a710ab":[6,0,0,4,40,4],
"classviennacl_1_1linalg_1_1power__iter__tag.html#af75af4cbe75d54d797ce1cc3907d7741":[6,0,0,4,40,0],
"classviennacl_1_1linalg_1_1row__scaling.html":[6,0,0,4,41],
"classviennacl_1_1linalg_1_1row__scaling.html#a772edd12410c3d582f4ad4f3d1bcd110":[6,0,0,4,41,1],
"classviennacl_1_1linalg_1_1row__scaling.html#aa72db3a13d55bccc107e4c83e6663aee":[6,0,0,4,41,0],
"classviennacl_1_1linalg_1_1row__scaling.html#af749c6f614c4ca03919098f29486da37":[6,0,0,4,41,2],
"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html":[6,0,0,4,42],
"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#a1bd03c552dcc799006641e233da7c301":[6,0,0,4,42,0],
"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#a23fc95af614b76b6c6a152a44dfa5f7c":[6,0,0,4,42,1],
"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html#ad808b8c0aa51c598225e6d1807df2ab1":[6,0,0,4,42,2],
"classviennacl_1_1linalg_1_1row__scaling__tag.html":[6,0,0,4,43],
"classviennacl_1_1linalg_1_1row__scaling__tag.html#a3c3bfb1f173289eb5e5e8e91c59d4e7d":[6,0,0,4,43,0],
"classviennacl_1_1linalg_1_1row__scaling__tag.html#aa53822390da5f7d7d497c71d706446d7":[6,0,0,4,43,1],
"classviennacl_1_1linalg_1_1spai__precond.html":[6,0,0,4,44],
"classviennacl_1_1linalg_1_1spai__precond.html#a3d149f1afa7719c358c7415f2f306e14":[6,0,0,4,44,3],
"classviennacl_1_1linalg_1_1spai__precond.html#a4a39605607ecf9095fad66426b11580e":[6,0,0,4,44,2],
"classviennacl_1_1linalg_1_1spai__precond.html#a6f10195cff888f10be69814616c6c4a0":[6,0,0,4,44,1],
"classviennacl_1_1linalg_1_1spai__precond.html#aa7f452bb409abe29b7d0835fc69728b3":[6,0,0,4,44,0],
"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html":[6,0,0,4,45],
"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#a964acb6fb9cda96c9ff15ad9e60dadb4":[6,0,0,4,45,0],
"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#aabfc6ef7298c66e9189107614fe1a297":[6,0,0,4,45,1],
"classviennacl_1_1matrix.html":[6,0,0,62],
"classviennacl_1_1matrix.html#a1de4d71a10ba9b60a01005bae51027b5":[6,0,0,62,0],
"classviennacl_1_1matrix.html#a69431725e09b2b73606dee084c962d7f":[6,0,0,62,14],
"classviennacl_1_1matrix.html#a8a5ce7e676c57d1f0acd746951d32fec":[6,0,0,62,9],
"classviennacl_1_1matrix.html#a997df903eca9afe7f58d7932c7aa5c8e":[6,0,0,62,11],
"classviennacl_1_1matrix.html#aa1d160f8ee553be461e27550d33a774e":[6,0,0,62,1],
"classviennacl_1_1matrix.html#aacc576b44b1377555030469c493a2b9e":[6,0,0,62,13],
"classviennacl_1_1matrix.html#ab3ef00115276f179a8cd2172f9738e33":[6,0,0,62,3],
"classviennacl_1_1matrix.html#ab8eb950050017f961faf5ac0184e934c":[6,0,0,62,8],
"classviennacl_1_1matrix.html#ac3cd72a83b58d55a61357669bee23b38":[6,0,0,62,2],
"classviennacl_1_1matrix.html#ac8dad9e664244e4a6dd9f45e061a4adc":[6,0,0,62,7],
"classviennacl_1_1matrix.html#ad5fde9fad4e61456dfd9a4818bf210d0":[6,0,0,62,10],
"classviennacl_1_1matrix.html#adae9b1fad83885bd3162031e012ed3ea":[6,0,0,62,4],
"classviennacl_1_1matrix.html#adde2f19fc84b9d96db059b9bb9af448d":[6,0,0,62,5],
"classviennacl_1_1matrix.html#aeab900b21767b83178cc4bd3ce303d41":[6,0,0,62,12],
"classviennacl_1_1matrix.html#aedafac235f345bca2e555930a748415d":[6,0,0,62,6],
"classviennacl_1_1matrix__base.html":[6,0,0,63],
"classviennacl_1_1matrix__base.html#a00e30fdc61081a73995b54175a91d220":[6,0,0,63,21],
"classviennacl_1_1matrix__base.html#a033e870a0bee332152772e7320b674f7":[6,0,0,63,53],
"classviennacl_1_1matrix__base.html#a050371bcbfcc677b0514f1a00c9bdf67":[6,0,0,63,4],
"classviennacl_1_1matrix__base.html#a0871683c6bdf478a8875a9680c125729":[6,0,0,63,63],
"classviennacl_1_1matrix__base.html#a0a523347f5392d5afd43c6b41cbbc6ce":[6,0,0,63,60],
"classviennacl_1_1matrix__base.html#a15ec879f9e85a6fc209454b0bf137084":[6,0,0,63,56],
"classviennacl_1_1matrix__base.html#a1ed2e5522cc93025b8168884e87f21c0":[6,0,0,63,14],
"classviennacl_1_1matrix__base.html#a1fcdecebef3ea1a4892d06ee4840d506":[6,0,0,63,39],
"classviennacl_1_1matrix__base.html#a21c79063d8aa5108bdec78b7ee720da8":[6,0,0,63,26],
"classviennacl_1_1matrix__base.html#a24e4f5fa27a1af5ad47e52a97c065d68":[6,0,0,63,58],
"classviennacl_1_1matrix__base.html#a25b797fdf4d3c841cae4d047f9cfbaee":[6,0,0,63,40],
"classviennacl_1_1matrix__base.html#a28087e6cd79a3eb13df18b40092966d3":[6,0,0,63,62],
"classviennacl_1_1matrix__base.html#a2896fa7b137959c57bcb5966a2a37870":[6,0,0,63,27],
"classviennacl_1_1matrix__base.html#a2a789435ff884ce9f1ff9d65025ba3e7":[6,0,0,63,3],
"classviennacl_1_1matrix__base.html#a2b8c9fe73ee98c4a55ac0d116ee9df38":[6,0,0,63,5],
"classviennacl_1_1matrix__base.html#a2cdca5a19d0e0d46a0ace69f1724b714":[6,0,0,63,30],
"classviennacl_1_1matrix__base.html#a2dc5bd36497cb6a39d010ed447a12fdf":[6,0,0,63,47],
"classviennacl_1_1matrix__base.html#a31b060a53ecced4caa6a41ef13e64d43":[6,0,0,63,32],
"classviennacl_1_1matrix__base.html#a33997bfe92e860894b22f5bb518a1290":[6,0,0,63,7],
"classviennacl_1_1matrix__base.html#a38f0caaff139f738da4d629a19eb8133":[6,0,0,63,50],
"classviennacl_1_1matrix__base.html#a4082cd3586bc99deb68733257b30c51f":[6,0,0,63,17],
"classviennacl_1_1matrix__base.html#a4348766b3b9cb049f7acd6a795272dbe":[6,0,0,63,59],
"classviennacl_1_1matrix__base.html#a49f216cbcd3c8ac055bf10727df36bb5":[6,0,0,63,57],
"classviennacl_1_1matrix__base.html#a4d68a8dc9bdca6b231f5eaffab98b3ec":[6,0,0,63,16],
"classviennacl_1_1matrix__base.html#a5239f29ffd79c36d9554cb1b79ae8c09":[6,0,0,63,29],
"classviennacl_1_1matrix__base.html#a555de07c987b3f8dfa6778ef29887788":[6,0,0,63,37],
"classviennacl_1_1matrix__base.html#a55f4fded82d61ad7d193cf3080bf6761":[6,0,0,63,36],
"classviennacl_1_1matrix__base.html#a64319ec4bd226ca34e262dacb2092ded":[6,0,0,63,8],
"classviennacl_1_1matrix__base.html#a64faacf51cfa7b520268fc625af928c7":[6,0,0,63,35],
"classviennacl_1_1matrix__base.html#a69ce70a1df8ae8f97dd022b43fc81abe":[6,0,0,63,9],
"classviennacl_1_1matrix__base.html#a72ccdf250016fdd4599dfae6994b084c":[6,0,0,63,24],
"classviennacl_1_1matrix__base.html#a73e4c43075e9b9cb229d4fc9edf0f53f":[6,0,0,63,45],
"classviennacl_1_1matrix__base.html#a74ba45afe7c6c22128463a7a9eece697":[6,0,0,63,55],
"classviennacl_1_1matrix__base.html#a7a6d23943b12cf193cfc8439f10c5239":[6,0,0,63,31],
"classviennacl_1_1matrix__base.html#a7b8e8b021a29d73f43af3f1f4c36ecbc":[6,0,0,63,44],
"classviennacl_1_1matrix__base.html#a7cd6f5dc0261fa507d78679bacce8ff3":[6,0,0,63,12],
"classviennacl_1_1matrix__base.html#a7d81490156aa0b0f8d6e268a01b954c5":[6,0,0,63,6],
"classviennacl_1_1matrix__base.html#a7f1b176eaa22875c3dc04750498616a1":[6,0,0,63,19],
"classviennacl_1_1matrix__base.html#a82018b4e169973bdfb9d3be68ceb5be0":[6,0,0,63,20],
"classviennacl_1_1matrix__base.html#a871a2766915f1ac53f9b906a5a6ece99":[6,0,0,63,38],
"classviennacl_1_1matrix__base.html#a89b777f4dbd07ecc26f251192107539d":[6,0,0,63,64],
"classviennacl_1_1matrix__base.html#a97a05d0d15287911969ee656268e957d":[6,0,0,63,0],
"classviennacl_1_1matrix__base.html#a9d4b62d3c58f685b0625131ce08a85ab":[6,0,0,63,18],
"classviennacl_1_1matrix__base.html#a9e3d2257ed3bd0a67a0844aead9f9560":[6,0,0,63,48],
"classviennacl_1_1matrix__base.html#a9f7c56940f0779f63ed30a85534b29e3":[6,0,0,63,49],
"classviennacl_1_1matrix__base.html#a9f852147d9189e221aa2233956e45512":[6,0,0,63,13],
"classviennacl_1_1matrix__base.html#aa867b9e7459398ad43bf6d5db4099589":[6,0,0,63,1],
"classviennacl_1_1matrix__base.html#aa94289bd12b7cf72cde9671747aad467":[6,0,0,63,54],
"classviennacl_1_1matrix__base.html#ab342aa19ffdb8ba553140f44d1fd4092":[6,0,0,63,15],
"classviennacl_1_1matrix__base.html#ab4a24cdcf2bed1c6eb83532584cebaed":[6,0,0,63,28],
"classviennacl_1_1matrix__base.html#ac486bcceee85716926ddefa762d5425f":[6,0,0,63,2],
"classviennacl_1_1matrix__base.html#ac664dd7f9b647657b14d56ba2978ba59":[6,0,0,63,11],
"classviennacl_1_1matrix__base.html#ac7b6e3646eb0fd666bd503ca91971f8b":[6,0,0,63,42],
"classviennacl_1_1matrix__base.html#accaa312b60fca452d152fb260a3429b9":[6,0,0,63,34],
"classviennacl_1_1matrix__base.html#ace341780fc4c5533e2818ec3cafe26cb":[6,0,0,63,22],
"classviennacl_1_1matrix__base.html#ad4ca29d5901cf2249199db3be5ee0e72":[6,0,0,63,41],
"classviennacl_1_1matrix__base.html#ad5ff0f40c43720312c655b232436c14c":[6,0,0,63,43],
"classviennacl_1_1matrix__base.html#adc3585292c6d5bf3076dea46a9895289":[6,0,0,63,33],
"classviennacl_1_1matrix__base.html#ae0b8e1d66c44b4ebe8ec71516a36d572":[6,0,0,63,46],
"classviennacl_1_1matrix__base.html#ae7e59905da4da81d72faa4f1dabc92ea":[6,0,0,63,52],
"classviennacl_1_1matrix__base.html#aea8dcaba5a60e427b8712cefc1adb829":[6,0,0,63,51],
"classviennacl_1_1matrix__base.html#aeea51bfd213766338c847bf92117323c":[6,0,0,63,10],
"classviennacl_1_1matrix__base.html#af141f5216626734e44b8845981b54b0f":[6,0,0,63,61],
"classviennacl_1_1matrix__base.html#af73da8b36b54893fcb47beffab9312fa":[6,0,0,63,25],
"classviennacl_1_1matrix__base.html#aff9e2bae9a01d135bd089b1d3bacf6d1":[6,0,0,63,23],
"classviennacl_1_1matrix__expression.html":[6,0,0,64],
"classviennacl_1_1matrix__expression.html#a3125cc5f209063de6a99dc67e19d42bb":[6,0,0,64,4],
"classviennacl_1_1matrix__expression.html#a417180fdbc1a844aa9dc6b93fa9fbd9d":[6,0,0,64,0],
"classviennacl_1_1matrix__expression.html#a5e1aa68cd901d54ed3e4bc56882a5047":[6,0,0,64,3],
"classviennacl_1_1matrix__expression.html#a7bcf8a5fcdea84fba7fe989749791417":[6,0,0,64,1],
"classviennacl_1_1matrix__expression.html#aa2c582e8d2c1cafbf2ffdf05c9fdfaca":[6,0,0,64,2],
"classviennacl_1_1matrix__expression.html#ad8516f3a2ef4db4d5379fb64832fd39f":[6,0,0,64,5],
"classviennacl_1_1matrix__iterator.html":[6,0,0,65],
"classviennacl_1_1matrix__iterator.html#a121be30f9b9c7585e30d14dd0cdcc6a3":[6,0,0,65,0],
"classviennacl_1_1matrix__iterator.html#a1d773c1b5ee19bc68b400442a9550e2e":[6,0,0,65,4],
"classviennacl_1_1matrix__iterator.html#a2cab0902708eef3409d060525e7b1bd3":[6,0,0,65,7],
"classviennacl_1_1matrix__iterator.html#a4801a7780c28b98488cfb2bf75c668c3":[6,0,0,65,6],
"classviennacl_1_1matrix__iterator.html#a4ef6bffdf5f728b0bbba6ba175a0a4d9":[6,0,0,65,8],
"classviennacl_1_1matrix__iterator.html#a6831a7e228fd80e84711d82e2362c6db":[6,0,0,65,5],
"classviennacl_1_1matrix__iterator.html#a70cfd358baf22f4ee9570f1a6b7c1701":[6,0,0,65,2],
"classviennacl_1_1matrix__iterator.html#a817d81d889d73ac2dc6e6177e062bd7a":[6,0,0,65,1],
"classviennacl_1_1matrix__iterator.html#a895218ddd37e5f964c30bc89d0cd1781":[6,0,0,65,9],
"classviennacl_1_1matrix__iterator.html#ac35c319df57718089c7f39d97733e1ba":[6,0,0,65,3],
"classviennacl_1_1matrix__range.html":[6,0,0,66],
"classviennacl_1_1matrix__range.html#a100b1ddda26bfd792b34b666c0dc23e2":[6,0,0,66,8],
"classviennacl_1_1matrix__range.html#a1d46c33083bf7c74898c69801c25e8cb":[6,0,0,66,10],
"classviennacl_1_1matrix__range.html#a294649e885898124628094aa3acd5fa5":[6,0,0,66,4],
"classviennacl_1_1matrix__range.html#a2bd2b1d5a66cb256ae3ebcefcdc10183":[6,0,0,66,11],
"classviennacl_1_1matrix__range.html#a3a6b55a656dc7ad97e7d2ad9aa625f18":[6,0,0,66,9],
"classviennacl_1_1matrix__range.html#a4064dc2a15d3ab796852dffb6cfd873b":[6,0,0,66,1],
"classviennacl_1_1matrix__range.html#a6178a1a8edf196ce5032738da4877b25":[6,0,0,66,7],
"classviennacl_1_1matrix__range.html#a6d841c457f8442372f9478d968f1fd1b":[6,0,0,66,2],
"classviennacl_1_1matrix__range.html#ab15ae025d7115f09d1c9687c24474321":[6,0,0,66,12],
"classviennacl_1_1matrix__range.html#ad436ae3cbfcb2ab134f4b8727828259e":[6,0,0,66,6],
"classviennacl_1_1matrix__range.html#ae6dc2ea9e181e7305eb258397f2a75f1":[6,0,0,66,0],
"classviennacl_1_1matrix__range.html#aec19050aa8523003ebd04a0122c8bb2f":[6,0,0,66,5],
"classviennacl_1_1matrix__range.html#af11274e4ec8c01b269f6f928b34242c4":[6,0,0,66,3],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html":[6,0,0,67],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aa595c2260e61819b45437e38fe06169a":[6,0,0,67,2],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#ab399b835b9292482c71c2587834bfd7c":[6,0,0,67,1],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#ac046c47a64543a2e08fa700e2ca6b034":[6,0,0,67,0],
"classviennacl_1_1matrix__slice.html":[6,0,0,68],
"classviennacl_1_1matrix__slice.html#a30f8bdd48c7b3f3e470aab2a9d419bd7":[6,0,0,68,5],
"classviennacl_1_1matrix__slice.html#a383814f6e743f3e864dbe3b05dd8fa71":[6,0,0,68,3],
"classviennacl_1_1matrix__slice.html#a38cb8271a86001d19028cc2903546463":[6,0,0,68,1],
"classviennacl_1_1matrix__slice.html#a597f170c876f95c4c6bc3a019f3cedbd":[6,0,0,68,11],
"classviennacl_1_1matrix__slice.html#a73ec32d37eb9c64e2e165abbb7e6d87b":[6,0,0,68,9],
"classviennacl_1_1matrix__slice.html#a75ffb6e46e07e6ffe2dbaef2d6bb7593":[6,0,0,68,7],
"classviennacl_1_1matrix__slice.html#a957bc283ab8327eb93ce863c9a734f32":[6,0,0,68,8],
"classviennacl_1_1matrix__slice.html#a9f10a6601fa6afe0d38a8f1e6483a90c":[6,0,0,68,4],
"classviennacl_1_1matrix__slice.html#aa899c7446878be8a9200e741e4d57fe3":[6,0,0,68,6],
"classviennacl_1_1matrix__slice.html#aa8d028e30ba6472a9a632c49b9913e03":[6,0,0,68,12],
"classviennacl_1_1matrix__slice.html#ad540bf380c5586b66d6ba3745555136f":[6,0,0,68,0],
"classviennacl_1_1matrix__slice.html#ae6b654d0c84a931eb3432a5a7c8cd106":[6,0,0,68,10],
"classviennacl_1_1matrix__slice.html#afe786a1f980fa21ff95d338784021598":[6,0,0,68,2],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html":[6,0,0,69],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#a1405263a01e16f7bcd4c09fb8eb29bc7":[6,0,0,69,0],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aabe80bdcb1d57191aff173806d0b3e31":[6,0,0,69,1],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aef18c078f89c2851229dd91422fed2db":[6,0,0,69,2],
"classviennacl_1_1memory__exception.html":[6,0,0,70],
"classviennacl_1_1memory__exception.html#a0e8dfdd960da56daa8616f11780ffc3c":[6,0,0,70,2],
"classviennacl_1_1memory__exception.html#a2bd16efb8a50540d155c6eb81d5d45e4":[6,0,0,70,3],
"classviennacl_1_1memory__exception.html#a6ea59387f3ccdba0c559cb6a186ad7cc":[6,0,0,70,1],
"classviennacl_1_1memory__exception.html#abe5d81175f7dd39579b6337b90ea21ca":[6,0,0,70,0],
"classviennacl_1_1ocl_1_1backend.html":[6,0,0,5,1],
"classviennacl_1_1ocl_1_1build__program__failure.html":[6,0,0,5,2],
"classviennacl_1_1ocl_1_1command__queue.html":[6,0,0,5,3],
"classviennacl_1_1ocl_1_1command__queue.html#a31862d3455bd31b51ecdcdadebbbde79":[6,0,0,5,3,2],
"classviennacl_1_1ocl_1_1command__queue.html#a4516024c4cec5147e582ca85e0fe1f00":[6,0,0,5,3,4],
"classviennacl_1_1ocl_1_1command__queue.html#a670f2d080528e50d64d3912567708754":[6,0,0,5,3,5],
"classviennacl_1_1ocl_1_1command__queue.html#a932d287769eebe9ef045ab85b4575706":[6,0,0,5,3,7],
"classviennacl_1_1ocl_1_1command__queue.html#a93a510254baa209cbfcab51eda30e780":[6,0,0,5,3,1],
"classviennacl_1_1ocl_1_1command__queue.html#ab38b51dc74556adb044ea9f8e4c458e9":[6,0,0,5,3,6],
"classviennacl_1_1ocl_1_1command__queue.html#ae2e51d158444a51341af30cebc5cf88b":[6,0,0,5,3,3],
"classviennacl_1_1ocl_1_1command__queue.html#af9ace720a0aae631ac5eaf791c6c6160":[6,0,0,5,3,8],
"classviennacl_1_1ocl_1_1command__queue.html#afe48096ca16c17701bc016df6854ca80":[6,0,0,5,3,0],
"classviennacl_1_1ocl_1_1compiler__not__available.html":[6,0,0,5,4],
"classviennacl_1_1ocl_1_1context.html":[6,0,0,5,5],
"classviennacl_1_1ocl_1_1context.html#a0f1a9e025d6fcdd44b21d8f80fa8c446":[6,0,0,5,5,0],
"classviennacl_1_1ocl_1_1context.html#a122abd131e682733ff44bdf480365ba2":[6,0,0,5,5,23],
"classviennacl_1_1ocl_1_1context.html#a1b1339c711fd666c8bdc9104f47670d4":[6,0,0,5,5,25],
"classviennacl_1_1ocl_1_1context.html#a2579803294df7a517efc5551e02ca9ec":[6,0,0,5,5,7],
"classviennacl_1_1ocl_1_1context.html#a27347b71cec98f6636de39e91e767f4f":[6,0,0,5,5,21],
"classviennacl_1_1ocl_1_1context.html#a2af175f7e99efa33ad852ab3d871f666":[6,0,0,5,5,22],
"classviennacl_1_1ocl_1_1context.html#a3b505875590e899db5538daf05f74b05":[6,0,0,5,5,6],
"classviennacl_1_1ocl_1_1context.html#a43602c712b8c33cf6c9c5eeebdbe0eb7":[6,0,0,5,5,35],
"classviennacl_1_1ocl_1_1context.html#a4ad17f85bfc2e5715c9e327c40138d43":[6,0,0,5,5,42],
"classviennacl_1_1ocl_1_1context.html#a4f0b8c81dad769f6efffe2d2069101f8":[6,0,0,5,5,8],
"classviennacl_1_1ocl_1_1context.html#a4f89a62af0d767fd8a4f5f07323447ea":[6,0,0,5,5,38],
"classviennacl_1_1ocl_1_1context.html#a562e2d1a9a55e647570734c4f62a22e2":[6,0,0,5,5,9],
"classviennacl_1_1ocl_1_1context.html#a566dfbe8b8e1588ae21c50091682d1ce":[6,0,0,5,5,19],
"classviennacl_1_1ocl_1_1context.html#a611d95b11db04230f63e37bfeae911db":[6,0,0,5,5,32],
"classviennacl_1_1ocl_1_1context.html#a6aa5ef5cb563ed047ff72f286eb5718b":[6,0,0,5,5,10],
"classviennacl_1_1ocl_1_1context.html#a734307b352a0137c93f22cfebed89dfe":[6,0,0,5,5,2],
"classviennacl_1_1ocl_1_1context.html#a7ccf3c2f3be355f39ea07cfea9600369":[6,0,0,5,5,1],
"classviennacl_1_1ocl_1_1context.html#a7e593822095e5680fc8de44e34cb4131":[6,0,0,5,5,34],
"classviennacl_1_1ocl_1_1context.html#a83052a42aed14d8ff9d3df4773908f64":[6,0,0,5,5,27],
"classviennacl_1_1ocl_1_1context.html#a85373fa81be824eef324579bf429d201":[6,0,0,5,5,41],
"classviennacl_1_1ocl_1_1context.html#a8ac887230ee381a0f5f9df2a22129155":[6,0,0,5,5,37]
};
